//		Copyright © 1997–1999  Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//		$Log: SamhainView.cpp,v $
//		Revision 1.1  1999/01/10 09:44:16  jjk
//		Initial revision
//

//		A view displaying a simple knot.

#include <GraphicsDefs.h>
#include <Point.h>
#include <Rect.h>
#include <View.h>

#include "KnotSection.h"
#include "KnotSectionCache.h"
#include "SamhainView.h"

SamhainView::SamhainView(BRect frame)
:	inherited(frame, "Samhain", B_FOLLOW_ALL, B_WILL_DRAW),
	mCache(frame.Height() / 3.0, 0.45, 0.35, false)
{
	// empty
}
	
SamhainView::~SamhainView(void)
{
	// empty
}
	
void
SamhainView::AttachedToWindow(void)
{
	inherited::AttachedToWindow();
	
	SetViewColor(100, 255, 100);
	SetLowColor(100, 255, 100);
	SetHighColor(0, 150, 0);
}

void
SamhainView::Draw(BRect /*updateRect*/)
{
	const float offset = mCache.EdgeLength() * 0.5;

	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(V, N, H, N, D)),
						 BPoint(-offset, 0.0));
	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(D, H, H, D, V)),
						 BPoint(offset, 0.0));
	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(D, H, H, V, D)),
						 BPoint(3.0*offset, 0.0));
	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(V, H, N, D, N)),
						 BPoint(5.0*offset, 0.0));

	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(V, N, D, N, H)),
						 BPoint(-offset, 2.0*offset));
	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(D, D, V, H, D)),
						 BPoint(offset, 2.0*offset));
	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(D, V, D, D, H)),
						 BPoint(3.0*offset, 2.0*offset));
	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(V, D, N, H, N)),
						 BPoint(5.0*offset, 2.0*offset));

	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(V, N, H, N, H)),
						 BPoint(-offset, 4.0*offset));
	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(D, H, D, H, H)),
						 BPoint(offset, 4.0*offset));
	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(D, D, H, H, H)),
						 BPoint(3.0*offset, 4.0*offset));
	DrawBitmapAsync(mCache.GetKnotSection(KnotSection(V, H, N, H, N)),
						 BPoint(5.0*offset, 4.0*offset));
	
	Sync();
}

static char RCSid[] = "$Id: SamhainView.cpp,v 1.1 1999/01/10 09:44:16 jjk Exp $";
